@@ -8,25 +8,22 @@
 #define OPENBLAS_PTHREAD_CREATE_FUNC pthread_create
 #define OPENBLAS_BUNDERSCORE _
 #define OPENBLAS_NEEDBUNDERSCORE 1
-#define OPENBLAS_COOPERLAKE 
+#define OPENBLAS_HASWELL 
 #define OPENBLAS_L1_CODE_SIZE 32768
 #define OPENBLAS_L1_CODE_ASSOCIATIVE 8
 #define OPENBLAS_L1_CODE_LINESIZE 64
 #define OPENBLAS_L1_DATA_SIZE 32768
 #define OPENBLAS_L1_DATA_ASSOCIATIVE 8
 #define OPENBLAS_L1_DATA_LINESIZE 64
-#define OPENBLAS_L2_SIZE 1048576
+#define OPENBLAS_L2_SIZE 262144
 #define OPENBLAS_L2_ASSOCIATIVE 8
 #define OPENBLAS_L2_LINESIZE 64
-#define OPENBLAS_L3_SIZE 201326592
-#define OPENBLAS_L3_ASSOCIATIVE 9
-#define OPENBLAS_L3_LINESIZE 64
-#define OPENBLAS_ITB_SIZE 4096
+#define OPENBLAS_ITB_SIZE 2097152
 #define OPENBLAS_ITB_ASSOCIATIVE 0
-#define OPENBLAS_ITB_ENTRIES 64
+#define OPENBLAS_ITB_ENTRIES 8
 #define OPENBLAS_DTB_SIZE 4096
-#define OPENBLAS_DTB_ASSOCIATIVE 0
-#define OPENBLAS_DTB_DEFAULT_ENTRIES 72
+#define OPENBLAS_DTB_ASSOCIATIVE 4
+#define OPENBLAS_DTB_DEFAULT_ENTRIES 64
 #define OPENBLAS_HAVE_CMOV 
 #define OPENBLAS_HAVE_MMX 
 #define OPENBLAS_HAVE_SSE 
@@ -35,26 +32,21 @@
 #define OPENBLAS_HAVE_SSSE3 
 #define OPENBLAS_HAVE_SSE4_1 
 #define OPENBLAS_HAVE_SSE4_2 
-#define OPENBLAS_HAVE_SSE4A 
 #define OPENBLAS_HAVE_AVX 
 #define OPENBLAS_HAVE_AVX2 
-#define OPENBLAS_HAVE_AVX512VL 
-#define OPENBLAS_HAVE_AVX512BF16 
 #define OPENBLAS_HAVE_FMA3 
 #define OPENBLAS_HAVE_CFLUSH 
-#define OPENBLAS_HAVE_MISALIGNSSE 
-#define OPENBLAS_HAVE_FASTMOVU 
-#define OPENBLAS_NUM_SHAREDCACHE 1
-#define OPENBLAS_NUM_CORES 1
-#define OPENBLAS_CORE_COOPERLAKE 
-#define OPENBLAS_CHAR_CORENAME "COOPERLAKE"
+#define OPENBLAS_NUM_SHAREDCACHE 2
+#define OPENBLAS_NUM_CORES 8
+#define OPENBLAS_CORE_HASWELL 
+#define OPENBLAS_CHAR_CORENAME "HASWELL"
 #define OPENBLAS_SLOCAL_BUFFER_SIZE 20480
-#define OPENBLAS_DLOCAL_BUFFER_SIZE 12288
-#define OPENBLAS_CLOCAL_BUFFER_SIZE 12288
-#define OPENBLAS_ZLOCAL_BUFFER_SIZE 8192
+#define OPENBLAS_DLOCAL_BUFFER_SIZE 32768
+#define OPENBLAS_CLOCAL_BUFFER_SIZE 16384
+#define OPENBLAS_ZLOCAL_BUFFER_SIZE 12288
 #define OPENBLAS_GEMM_MULTITHREAD_THRESHOLD 4
 #define OPENBLAS_EXPRECISION 
-#define OPENBLAS_VERSION " OpenBLAS 0.3.30 "
+#define OPENBLAS_VERSION " OpenBLAS 0.3.31 "
 /*This is only for "make install" target.*/
 
 #if defined(OPENBLAS_OS_WINNT) || defined(OPENBLAS_OS_CYGWIN_NT) || defined(OPENBLAS_OS_INTERIX)
@@ -96,6 +88,13 @@ typedef unsigned long BLASULONG;
 typedef uint16_t bfloat16;
 #endif
 
+#if defined(__GNUC__) && (__GNUC__ >= 12)
+typedef _Float16 hfloat16;
+#else
+#include <stdint.h>
+typedef uint16_t hfloat16;
+#endif
+
 #ifdef OPENBLAS_USE64BITINT
 typedef BLASLONG blasint;
 #else
